rm(list=ls())
# setwd("~/Kalla Porter QJPS Replication/output")

# This code assumes you have first run fig1a_get_margins_for_results_plots.do
# That code generates the means and CIs used in the plots

library(ggplot2)
library(ggpubr)

# Generate a plot of the ambition index
ambition <- read.csv("ambitions_index.csv", as.is = TRUE)
ambition$post.label <- ifelse(ambition$post == 1, "Post", "Baseline")
ambition.plot <- ggplot(ambition, aes(x = gender_label, y = margin, group = post.label, colour = post.label)) + 
  geom_point(shape=21, fill="white", position=position_dodge(width=0.5)) +
  geom_errorbar(aes(ymin = ci_lb, ymax = ci_ub), width = 0.1, 
                position=position_dodge(width=0.5)) +
  ylab("Ambition Index") +
  xlab("") + 
  theme_bw() + 
  theme(legend.title=element_blank())

# Generate a plot of running for office scale
run.scale <- read.csv("ambitions_2.csv", as.is = TRUE)
run.scale$post.label <- ifelse(run.scale$post == 1, "Post", "Baseline")
run.scale.plot <- ggplot(run.scale, aes(x = gender_label, y = margin, group = post.label, colour = post.label)) + 
  geom_point(shape=21, fill="white", position=position_dodge(width=0.5)) +
  geom_errorbar(aes(ymin = ci_lb, ymax = ci_ub), width = 0.1, 
                position=position_dodge(width=0.5)) +
  ylab("Run for Office: 7-pt scale") +
  xlab("") + 
  theme_bw() + 
  theme(legend.title=element_blank())

# Generate a plot of efficacy index
efficacy <- read.csv("efficacy_index.csv", as.is = TRUE)
efficacy$post.label <- ifelse(efficacy$post == 1, "Post", "Baseline")
efficacy.plot <- ggplot(efficacy, aes(x = gender_label, y = margin, group = post.label, colour = post.label)) + 
  geom_point(shape=21, fill="white", position=position_dodge(width=0.5)) +
  geom_errorbar(aes(ymin = ci_lb, ymax = ci_ub), width = 0.1, 
                position=position_dodge(width=0.5)) +
  ylab("Efficacy Index") +
  xlab("") + 
  theme_bw() + 
  theme(legend.title=element_blank())

# Generate a plot of the binary run for office measure
run.binary <- read.csv("ambitions_2_binary.csv", as.is = TRUE)
run.binary$post.label <- ifelse(run.binary$post == 1, "Post", "Baseline")
run.binary.plot <- ggplot(run.binary, aes(x = gender_label, y = margin, group = post.label, colour = post.label)) + 
  geom_point(shape=21, fill="white", position=position_dodge(width=0.5)) +
  geom_errorbar(aes(ymin = ci_lb, ymax = ci_ub), width = 0.1, 
                position=position_dodge(width=0.5)) +
  ylab("Run for Office: binary measure") +
  xlab("") + 
  scale_y_continuous(labels = scales::percent_format(accuracy = 1)) + 
  theme_bw() + 
  theme(legend.title=element_blank())

combine.plot <- ggarrange(
  ambition.plot, efficacy.plot, run.scale.plot, run.binary.plot, 
  labels = c("A", "B", "C", "D"),
  common.legend = TRUE
)


jpeg("results.jpg", res = 600, height=7, width=7, units="in")
annotate_figure(combine.plot, bottom = text_grob(
  "Note: for all outcomes, no differences in the treatment effect of L'Taken\nbetween male and female respondents were statistically significant.",
  hjust = 1, x = 0.97, size = 10, face = "italic"))
dev.off()
  